//
// Copyright (c) 2004-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.contrib.adapter.sharedexample;

import java.beans.*;
import java.util.LinkedList;
import java.util.List;

import com.streambase.sb.operator.parameter.*;

/**
 * A BeanInfo class controls what properties are exposed, add 
 * metadata about properties (such as which properties are optional), and access 
 * special types of properties that can't be automatically derived via reflection. 
 * If a BeanInfo class is present, only the properties explicitly declared in
 * this class will be exposed by StreamBase.
 */
public class SharedInputAdapterBeanInfo extends SimpleBeanInfo
{
	public static final String SHARED_SETTING_PROPERTY_NAME = "settingForSharedObject";
	public static final String IS_SHARED_PROPERTY_NAME = "isSharedAdapter";
	public static final String SHARED_ADAPTER_PROPERTY_NAME = "SharedAdapter";
	
    /*
     * The order of properties below determines the order they are displayed within
     * the StreamBase Studio property view. 
     */
    public SBPropertyDescriptor[] getPropertyDescriptors()
    {
        try
        {
            List<PropertyDescriptor> p = new LinkedList<PropertyDescriptor>();

            p.add(new SBPropertyDescriptor(IS_SHARED_PROPERTY_NAME, SharedInputAdapter.class)
                    .displayName("Share With An Output Adapter")
                    .description("Check this option to share some state with the named 'Linked Output' adapter.")
                    .optional());
            
            //
            // Note the "fake" indentation of this setting to better associate it visually with the preceding one.
            //
            p.add(new SBPropertyDescriptor(SHARED_ADAPTER_PROPERTY_NAME, SharedInputAdapter.class)
                    .displayName("        Share With The Output Adapter Named")
                    .description("Set this to the name of a 'Linked Output' adapter with which you wish to share state.")
                    .optional());
            
            p.add(new SBPropertyDescriptor(SHARED_SETTING_PROPERTY_NAME, SharedInputAdapter.class)
                    .displayName("Important Setting")
                    .description("Set this to a string you wish passed on to the shared object.")
                    .optional());

            return p.toArray(new SBPropertyDescriptor[0]);
        }
        catch (IntrospectionException e)
        {
            System.err.println("Failed to create property descriptors");
            e.printStackTrace();
            return null;
        }
    }
}
