//
// Copyright (c) 2004-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.contrib.adapter.sharedexample;

import java.beans.*;
import java.util.LinkedList;
import java.util.List;

import com.streambase.sb.operator.parameter.*;

/**
 * A BeanInfo class controls what properties are exposed, add 
 * metadata about properties (such as which properties are optional), and access 
 * special types of properties that can't be automatically derived via reflection. 
 * If a BeanInfo class is present, only the properties explicitly declared in
 * this class will be exposed by StreamBase.
 */
public class SharedOutputAdapterBeanInfo extends SimpleBeanInfo
{
	public static final String SHARED_SETTING_PROPERTY_NAME = "settingForSharedObject";
    /*
     * The order of properties below determines the order they are displayed within
     * the StreamBase Studio property view. 
     */
    public SBPropertyDescriptor[] getPropertyDescriptors()
    {
        try
        {
            List<SBPropertyDescriptor> p = new LinkedList<SBPropertyDescriptor>();
            
            p.add(new SBPropertyDescriptor(SHARED_SETTING_PROPERTY_NAME, SharedOutputAdapter.class)
                        .displayName("Setting To Initialize Shared Object")
                        .description("Set this to a string you wish passed on to the shared object."));

            return p.toArray(new SBPropertyDescriptor[0]);
        }
        catch (IntrospectionException e)
        {
            System.err.println("Failed to create property descriptors");
            e.printStackTrace();
            return null;
        }
    }
}
